Various XAG optimization algorithms
-----------------------------------

**Header:** ``mockturtle/algorithms/xag_optimization.hpp``

.. doxygenfunction:: mockturtle::xag_constant_fanin_optimization
.. doxygenfunction:: mockturtle::xag_dont_cares_optimization
.. doxygenfunction:: mockturtle::linear_resynthesis_optimization
.. doxygenfunction:: mockturtle::exact_linear_resynthesis_optimization
